@@ -22,7 +22,7 @@ sub showDir {
     $sSubfolder =~ s?/$??g;
     my $links = $sSubfolder =~ m?^(.*/)[^/]+$? ? $1 : $sSubfolder;
     my $fname =
-      $sSubfolder =~ m?^.*/([^/]+)$? ? qq(<span style="color:white">$1</span>) : $sSubfolder;
+      $sSubfolder =~ m?^.*/([^/]+)$? ? qq(<b>$1</b>) : $sSubfolder;
     $links =~ s?//?/?g;
     my $elinks     = uri_escape($links);
     my $esubfolder = uri_escape($sSubfolder);
@@ -33,14 +33,14 @@ sub showDir {
     my $newstate = $state ? 0 : 1;
     my @t = readFiles($sSubfolder, 0);
     my $fileview = new HTML::Menu::TreeView();
-  SWITCH: {
 
+    SWITCH: {
         if (defined param('sort')) {
             $fileview->sortTree(1);
             $fileview->desc($state ? 1 : 0);
             last SWITCH;
         }
-        if ($byColumn eq 0 or $byColumn eq 1 or $byColumn eq 2) {
+        if ($byColumn eq 0 or $byColumn eq 1 or $byColumn eq 2){
             $fileview->orderByColumn($byColumn);
             $fileview->desc($state ? 1 : 0);
             last SWITCH;
@@ -323,28 +323,23 @@ sub FileOpen {
             last SWITCH;
         }
         if (-T $f) {
-            print qq(<div align="center">)
-              . a({-href => "javascript:history.back()"}, translate('back'))
-              . "</div>";
             my $content = openFile($f);
             $content =~ s/<\/textarea>/[\%TEXTAREA\%]/gi;
-            &showEditor("Edit File: $f<br/>", $content, 'saveFile', $f);
+            &showEditor($f, $content, 'saveFile', $f);
             last SWITCH;
         } else {
-            print translate('no_ascii_file');
+            print br(). qq(<div align="center">).translate('no_ascii_file') . "</div>";
         }
         if ($f =~ /png|jpg|jpeg|gif$/ && $f =~ m~/var/www/htdocs/(.*)$~) {
             print br()
               . qq(<div align="center"><img alt="" src="/$1" align="center"/>)
               . br()
-              . a({-href => "javascript:history.back()"}, translate('back'))
               . "</div>";
             last SWITCH;
         }
         print br()
           . translate("UnsopportedFileType")
-          . br()
-          . a({-href => "javascript:history.back()"}, translate('back'));
+          . br();
     }
 }
 
@@ -364,7 +359,7 @@ sub saveFile {
         close $fh;
         rename "$sFile.bak", $sFile or warn "files.pl::saveFile $/ $! $/" if (-e "$sFile.bak");
         chmod(0755, $sFile) if ($sFile =~ m?\.pl?);
-        showDir();
+        FileOpen($sFile);
     } elsif (defined param('title') && defined param('file')) {
         my $sf = param('file') . '/' . param('title');
         open $fh, ">$sf.bak" or warn "files.pl::saveFile $/ $! $/ $sf $/";
@@ -374,23 +369,34 @@ sub saveFile {
         print $fh $txt;
         close $fh;
         rename "$sf.bak", $sf or warn "files.pl::saveFile $/ $! $/" if (-e "$sf.bak");
-        showDir();
+        FileOpen($sf);
     }
 }
 
 sub showEditor {
     my $h = shift;
     my $t = shift;
-    utf8::encode($t) if utf8::valid($t);    #fixme textedit akzeptiert kein unicode
+    eval{
+      use Search::Tools::UTF8;
+      unless (is_valid_utf8($t)) {
+	  utf8::decode($t);
+      }
+    };
     my $a       = shift;
     my $fi      = shift;
-    my $buttons = HTML::Editor::buttons($m_sStyle);
+    my $buttons = HTML::Editor::buttons($m_sStyle,0);
+    my $efl     = $h;
+    $efl =~s?^(.+)/([^/]+)$?$1?;
+    my $linkText = $h;
+    $linkText =~s?^(.+)/([^/]+)$?$1/<b>$2</b>?;
+    my $link =
+                  qq|<a href="javascript:requestURI('$m_hrSettings->{cgi}{serverName}$ENV{SCRIPT_NAME}?action=FileOpen&file=$efl','FileOpen','FileOpen')">$linkText</a>|;
     print qq|<div class="ShowTables marginTop">
     <form accept-charset="utf-8" action ="$m_hrSettings->{cgi}{serverName}$ENV{SCRIPT_NAME}" onsubmit="submitForm(this,'$a','$a');return false;" method="post">
     <table cellspacing="5" cellpadding="0" border="0" align="center" summary="files.pl" width="95%">
       <tbody>
       <tr>
-	  <td>$h</td>
+	  <td>$link</td>
 	</tr>
 	<tr><td>$buttons</td></tr>
 	<tr>
@@ -406,7 +412,7 @@ sub showEditor {
 	</tr>
       </tbody>
     </table>
-    </form></div>|;
+    </form></div><script>html =1;</script>|;
 }
 
 sub newFile {
