@@ -1,3 +1,5 @@
+use utf8;
+use warnings;
 no warnings 'redefine';
 use vars qw(@menu $newAction);
 ChangeDb(
